==> v6.1.1.tar.gz: thinkadmin/plugin.md <==
## ThinkAdmin 插件生态

更多插件正在开发，敬请期待……

**目前已有的插件如下：**

> 后台基础 Admin 管理插件
> * 插件标识：`admin`
> * 插件包名：`zoujingli/think-plugs-admin`
> * 安装方式：`composer require zoujingli/think-plugs-admin`
> * 插件仓库：https://github.com/zoujingli/think-plugs-admin
> * 开源协议：MIT ( 免费开放 )

> 后台基础 WeChat 微信插件
> * 插件标识：`wechat`
> * 插件包名：`zoujingli/think-plugs-wechat`
> * 安装方式：`composer require zoujingli/think-plugs-wechat`
> * 插件仓库：https://github.com/zoujingli/think-plugs-wechat
> * 开源协议：MIT ( 免费开放 )

> 后台静态资源初始化插件（通常不需要独立安装）
> * 插件标识：`static`
> * 插件包名：`zoujingli/think-plugs-static`
> * 安装方式：`composer require zoujingli/think-plugs-static`
> * 插件仓库：https://github.com/zoujingli/think-plugs-static
> * 开源协议：MIT ( 免费开放，里面有部分其他开源协议，具体可以查看源文件 )

> 基础在线插件市场 ( 开发中，后期会成为 ThinkAdmin 生态市场 )
> * 插件标识：`plugin-center`
> * 插件包名：`zoujingli/think-plugs-center`
> * 安装方式：`composer require zoujingli/think-plugs-center`
> * 插件仓库：https://github.com/zoujingli/think-plugs-center
> * 开源协议：Apache2 ( 免费开放，里面有部分其他开源协议，具体可以查看源文件 )

> 基础商品管理插件（目前处于重构中，可以安装体验用）
> * 插件标识：`plugin-base-goods`
> * 插件包名：`zoujingli/think-plugs-base-goods`
> * 安装方式：`composer require zoujingli/think-plugs-base-goods dev-master`
> * 插件仓库：https://gitee.com/zoujingli/think-plugs-base-goods
> * 开源协议：MIT ( 免费开放 )

> 后台微信开放平台插件
> * 插件标识：`plugin-wechat-service`
> * 插件包名：`zoujingli/think-plugin-wechat-service`
> * 安装方式：`composer require zoujingli/think-plugin-wechat-service`
> * 插件仓库：https://github.com/zoujingli/think-plugs-wechat-service
> * 授权协议：VIP授权 ( 非VIP用户仅可用于学习，不得商用 )

==> v6.1.2.tar.gz: thinkadmin/plugin.md <==
## ThinkAdmin 插件生态

更多插件正在开发，敬请期待……

**目前已有的插件如下：**

> 后台基础 Admin 管理插件
> * 插件标识：`admin`
> * 插件包名：`zoujingli/think-plugs-admin`
> * 安装方式：`composer require zoujingli/think-plugs-admin`
> * 插件仓库：https://github.com/zoujingli/think-plugs-admin
> * 开源协议：MIT ( 免费开放 )

> 后台基础 WeChat 微信插件
> * 插件标识：`wechat`
> * 插件包名：`zoujingli/think-plugs-wechat`
> * 安装方式：`composer require zoujingli/think-plugs-wechat`
> * 插件仓库：https://github.com/zoujingli/think-plugs-wechat
> * 开源协议：MIT ( 免费开放 )

> 后台静态资源初始化插件（通常不需要独立安装）
> * 插件标识：`static`
> * 插件包名：`zoujingli/think-plugs-static`
> * 安装方式：`composer require zoujingli/think-plugs-static`
> * 插件仓库：https://github.com/zoujingli/think-plugs-static
> * 开源协议：MIT ( 免费开放，里面有部分其他开源协议，具体可以查看源文件 )

> 基础在线插件市场 ( 开发中，后期开放 ThinkAdmin 生态市场 )
> * 插件标识：`plugin-center`
> * 插件包名：`zoujingli/think-plugs-center`
> * 安装方式：`composer require zoujingli/think-plugs-center`
> * 插件仓库：https://github.com/zoujingli/think-plugs-center
> * 开源协议：Apache2 ( 免费开放，里面有部分其他开源协议，具体可以查看源文件 )

> 基础商品管理插件（目前处于重构中，可以安装体验用）
> * 插件标识：`plugin-base-goods`
> * 插件包名：`zoujingli/think-plugs-base-goods`
> * 安装方式：`composer require zoujingli/think-plugs-base-goods dev-master`
> * 插件仓库：https://gitee.com/zoujingli/think-plugs-base-goods
> * 开源协议：MIT ( 免费开放 )

> 后台微信开放平台插件
> * 插件标识：`plugin-wechat-service`
> * 插件包名：`zoujingli/think-plugin-wechat-service`
> * 安装方式：`composer require zoujingli/think-plugin-wechat-service`
> * 插件仓库：https://github.com/zoujingli/think-plugs-wechat-service
> * 授权协议：VIP授权 ( 非VIP用户仅可用于学习，不得商用 )
